@@ -17,6 +17,7 @@ enum class UserAgentFeature {
   S3_TRANSFER,
   S3_CRYPTO_V1N,
   S3_CRYPTO_V2,
+  S3_EXPRESS_BUCKET,
   FLEXIBLE_CHECKSUMS_REQ_CRC32,
   FLEXIBLE_CHECKSUMS_REQ_CRC32C,
   FLEXIBLE_CHECKSUMS_REQ_CRC64,
@@ -30,6 +31,7 @@ enum class UserAgentFeature {
   ACCOUNT_ID_MODE_DISABLED,
   ACCOUNT_ID_MODE_REQUIRED,
   RESOLVED_ACCOUNT_ID,
+  GZIP_REQUEST_COMPRESSION,
 };
 
 class AWS_CORE_API UserAgent {
